@@ -8,7 +8,7 @@ from .storage import storage
 from .lib.dupedict import DupeDict, JSON
 
 __author__ = 'Anton Hvornum'
-__version__ = '0.0.11'
+__version__ = '0.0.13'
 __description__ = "Our KVM solution, clulstered and self hosted"
 
 # Parse arguments early, so that following imports can
@@ -50,7 +50,7 @@ storage['arguments'].cluster_nodes = json.loads(storage['arguments'].cluster_nod
 
 # Expose API calls for when the user does `import ourkvm`:
 if args.api:
-	from .lib.api import app, User, get_current_user, get_current_user_information, list_all_known_cluster_nodes
+	from .lib.api import app, User, process_user_claim, get_current_user_information, list_all_known_cluster_nodes
 
 from .lib.logger import log
 from .lib.syscalls import SysCommand, SysCommandWorker
